# Recent changes

1.0.0 - 2022-04-15

- `--phmdoctest` option only does Python code/expected output.
- Add `--phmdoctest-docmod` option to do both:
  - Python code/expected output.
  - Python interactive sessions.
- Rename `--phmdoctest-save` option to `--phmdoctest-generate`.
- Collect Markdown only if it has Python examples.
- Runs on pytest 7, as well as 5.4.3 and 6.


0.0.3 - 2021-11-10

- Initial upload to Python Package Index.
